﻿using FichaBackend.Models;
using FichaBackend.Services;
using Microsoft.AspNetCore.Mvc;

namespace FichaBackend.Controllers;

[ApiController]
[Route("v1/")]
public class MainController : ControllerBase
{

    private readonly ILogger<MainController> _logger;
    private readonly IPublicDataService _publicDataService;

    public MainController(ILogger<MainController> logger, IPublicDataService publicDataService)
    {
        _logger = logger;
        _publicDataService = publicDataService;
    }
    
    [HttpGet("GetAllCity")]
    public async Task<IEnumerable<City>> GetAllCity()
    {
        return await _publicDataService.GetAllCity();
    }
    
    [HttpGet("GetAllCards")]
    public async Task<IEnumerable<CardQuestion>> GetAllCards()
    {
        return await _publicDataService.GetAllCards();
    }
    
    [HttpGet("GetAllFilmsInCity/{cityName}")]
    public async Task<ActionResult<IEnumerable<FilmDto>>> GetAllFilmsInCityWithPuskinCard(string cityName)
    {
        if (!_publicDataService.CityExsist(cityName))
            return BadRequest("City does not exsist");
        
        return Ok(await _publicDataService.GetAllFilmsInCity(cityName));
    }
    
    [HttpGet("GetAllMuseumsInCity/{cityName}")]
    public async Task<ActionResult<IEnumerable<Museum>>> GetAllMuseumsInCity(string cityName)
    {
        if (!_publicDataService.CityExsist(cityName))
            return BadRequest("City does not exsist");

        return Ok(await _publicDataService.GetAllMuseumsInCity(cityName));
    }
    
}